package sun.management;

import javax.management.ObjectName;
import java.util.Iterator;
import java.util.ArrayList;
import com.sun.management.VMOption;
import java.util.List;
import java.io.IOException;
import java.security.AccessController;
import com.sun.management.HotSpotDiagnosticMXBean;

public class HotSpotDiagnostic implements HotSpotDiagnosticMXBean
{
    public HotSpotDiagnostic() {
    }
    
    @Override
    public void dumpHeap(String file, boolean b) throws IOException {
        if (!(boolean)AccessController.doPrivileged(()/*  */ -> Boolean.valueOf(Boolean.parseBoolean(System.getProperty(key, "false")))) && !file.endsWith(".hprof")) {
            throw new IllegalArgumentException("heapdump file must have .hprof extention");
        }
        SecurityManager securityManager = System.getSecurityManager();
        if (securityManager != null) {
            securityManager.checkWrite(file);
            Util.checkControlAccess();
        }
        this.dumpHeap0(file, b);
        return;
    }
    
    private native void dumpHeap0(String p0, boolean p1) throws IOException;
    
    @Override
    public List<VMOption> getDiagnosticOptions() {
        List<Flag> allFlags = Flag.getAllFlags();
        ArrayList<VMOption> list = new ArrayList();
        for (Flag flag : allFlags) {
            if (flag.isWriteable() && flag.isExternal()) {
                list.add(flag.getVMOption());
            }
            else {
                continue;
            }
        }
        return list;
    }
    
    @Override
    public VMOption getVMOption(String str) {
        if (str == null) {
            throw new NullPointerException("name cannot be null");
        }
        Flag flag = Flag.getFlag(str);
        if (flag == null) {
            throw new IllegalArgumentException("VM option \"" + str + "\" does not exist");
        }
        return flag.getVMOption();
    }
    
    @Override
    public void setVMOption(String str, String s) {
        if (str == null) {
            throw new NullPointerException("name cannot be null");
        }
        if (s == null) {
            throw new NullPointerException("value cannot be null");
        }
        Util.checkControlAccess();
        Flag flag = Flag.getFlag(str);
        if (flag == null) {
            throw new IllegalArgumentException("VM option \"" + str + "\" does not exist");
        }
        if (!flag.isWriteable()) {
            throw new IllegalArgumentException("VM Option \"" + str + "\" is not writeable");
        }
        Object value = flag.getValue();
        if ((value instanceof Long)) {
            try {
                Flag.setLongValue(str, Long.parseLong(s));
            }
            catch (NumberFormatException cause) {
                IllegalArgumentException ex = new IllegalArgumentException("Invalid value: VM Option \"" + str + "\" expects numeric value");
                ex.initCause(cause);
                throw ex;
            }
        }
        else if ((value instanceof Boolean)) {
            if (!s.equalsIgnoreCase("true") && !s.equalsIgnoreCase("false")) {
                throw new IllegalArgumentException("Invalid value: VM Option \"" + str + "\" expects \"true\" or \"false\".");
            }
            Flag.setBooleanValue(str, Boolean.parseBoolean(s));
        }
        else if ((value instanceof String)) {
            Flag.setStringValue(str, s);
        }
        else {
            throw new IllegalArgumentException("VM Option \"" + str + "\" is of an unsupported type: " + value.getClass().getName());
        }
        return;
    }
    
    @Override
    public ObjectName getObjectName() {
        return Util.newObjectName("com.sun.management:type=HotSpotDiagnostic");
    }
}
